@@ -254,6 +254,13 @@ trimfill.meta <- function(x, left=NULL, ma.fixed=TRUE,
               df.hakn=m$df.hakn,
               method.tau=m$method.tau,
               prediction=prediction,
+              title=x$title,
+              complab=x$complab,
+              outclab=x$outclab,
+              label.e=x$label.e,
+              label.c=x$label.c,
+              label.left=x$label.left,
+              label.right=x$label.right,
               k0=sum(trimfill),
               level=level, level.comb=level.comb,
               comb.fixed=comb.fixed, comb.random=comb.random)
